# Generated by Django 2.2.6 on 2019-10-25 18:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('inputgooglesheets', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='spreadsheet',
            name='enabled',
            field=models.BooleanField(blank=True, default=True, verbose_name='Enabled'),
        ),
        migrations.AlterField(
            model_name='spreadsheet',
            name='omit_first_row',
            field=models.BooleanField(blank=True, default=True, verbose_name='Omit first row'),
        ),
    ]
