# Generated by Django 2.2.6 on 2019-10-26 02:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('inputgooglesheets', '0002_auto_20191025_1516'),
    ]

    operations = [
        migrations.AddField(
            model_name='spreadsheet',
            name='automatically_imported',
            field=models.BooleanField(blank=True, default=True, verbose_name='Automatically imported'),
        ),
    ]
